#!/usr/bin/perl -w 
# -*- perl -*-


use strict;

package CHIRP;


my($installRoot);

BEGIN {
	$installRoot = (($0 =~ m:^(.*/):)[0] || './') . '.';
}


use Getopt::Long;

use lib "$installRoot";
use lib::CHIRP;
use lib::Lowercase;
use lib::Parse;
use lib::WriteConfig;


my(%options);
my($Help) = 0;
my($deprecated);
my($hostname) = "";
my($community) = "public";
my($port) = "161";
my($idfile) = "id.cfg";
my($sitefile);
my($config);


%options = (
	"Help" => \$Help,
	"hostname" => \$deprecated,
	"community" => \$community,
	"port" => \$port,
	"idfile" => \$idfile,
	"sitefile" => \$sitefile
	);
Getopt::Long::Configure("no_ignore_case", "permute");
GetOptions(\%options, "-Help|?", "-hostname", "-community=s", "-port=i", "-idfile=s", "-sitefile=s");

if($Help == 1 || $#ARGV != 0) {
	print STDERR "Usage: $0 [-H] hostname [-c community] [-p port] [-i file] [-s file]\n",
		"\tRequired parameters:\n",
		"\t\thostname:        Hostname for SNMP query\n",
		"\n",
		"\tOptional parameters:\n",
		"\t\t-H|--Help:       This page\n",
		"\t\t-c|--community:  Community for SNMP query (Defaults to \"public\")\n",
		"\t\t-p|--port:       Port for SNMP query (Defaults to port 161)\n",
		"\t\t-i|--idfile:     ID config file\n",
		"\t\t-s|--sitefile:   Site config file\n";
	if ($Help != 1) {
		exit 1;
	}
	exit 0;
}


$hostname = $ARGV[0];
$config = CHIRP::CHIRP::GenConfig($hostname, $community, $port, $idfile, $sitefile);
if(!defined($config)) {
	print STDERR "ERROR: Failed to generate configuration via $community@$hostname:$port\n";
	exit 2;
}


if(CHIRP::WriteConfig::WriteConfig($config) != 0) {
	print STDERR "ERROR: Failed to write configuration\n";
	exit 2;
}

exit 0;
