#!/usr/bin/perl -w 
# -*- perl -*-


use strict;

package CHIRPId;


my($installRoot);

BEGIN {
	$installRoot = (($0 =~ m:^(.*/):)[0] || './') . '.';
}


use Getopt::Long;

use lib "$installRoot";
use lib::Identify;


my(%options);
my($Help) = 0;
my($deprecated);
my($hostname) = "";
my($community) = "public";
my($port) = "161";
my($idfile) = "id.cfg";
my($deviceTable);


%options = (
	"Help" => \$Help,
	"hostname" => \$deprecated,
	"community" => \$community,
	"port" => \$port,
	"idfile" => \$idfile
	);
Getopt::Long::Configure("no_ignore_case", "permute");
GetOptions(\%options, "-Help|?", "-hostname", "-community=s", "-port=i", "-idfile=s");
if($Help == 1 || $#ARGV != 0) {
	print STDERR "Usage: $0 [-H] hostname [-c community] [-p port] [-i file]\n",
		"\tRequired parameters:\n",
		"\t\thostname:        Hostname for SNMP query\n",
		"\n",
		"\tOptional parameters:\n",
		"\t\t-H|--Help:       This page\n",
		"\t\t-c|--community:  Community for SNMP query (Defaults to \"public\")\n",
		"\t\t-p|--port:       Port for SNMP query (Defaults to port 161)\n",
		"\t\t-i|--idfile:     ID config file\n";
	if ($Help != 1) {
		exit 1;
	}
	exit 0;
}


$hostname = $ARGV[0];
$deviceTable = CHIRP::Identify::Identify($hostname, $community, $port, $idfile);
if(!defined($deviceTable)) {
	print STDERR "ERROR: Failed to identify $community@$hostname:$port\n";
	exit 2;
}
if(!defined($deviceTable->{name})) {
	print STDERR "ERROR: Matched device does not seem to have a name.  Weird\n";
	exit 2;
}

print $deviceTable->{name} . "\n";

exit 0;
