#!/usr/bin/perl -w
# -*- perl -*-


use strict;

package CHIRPTree;


my($installRoot);

BEGIN {
	$installRoot = (($0 =~ m:^(.*/):)[0] || './') . '.';
}


use File::Path;
use Getopt::Long;

use lib "$installRoot";
use lib::CHIRP;
use lib::Lowercase;
use lib::Parse;
use lib::WriteConfig;


my(%options);
my($Help) = 0;
my($deprecated);
my($readstdin);
my($devicefile);
my($basedir);
my($idfile) = "id.cfg";
my($quiet) = 0;
my($hostname);
my($community);
my($port);
my($sitefile);
my($config);
my($SAVE_STDOUT);


%options = (
	"Help" => \$Help,
	"" => \$readstdin,
	"filename" => \$deprecated,
	"idfile" => \$idfile,
	"quiet" => \$quiet
	);
Getopt::Long::Configure("no_ignore_case", "permute");
GetOptions(\%options, "-Help|?", "-", "-file", "-idfile=s", "-quiet");

if($Help == 1 || (!defined($readstdin) && $#ARGV != 1) || (defined($readstdin) && $#ARGV != 0)) {
	print STDERR "Usage: $0 [-H] filename basedir [-i file] [-q]\n",
		"\tRequired parameters:\n",
		"\t\tfilename:        File with device list  (Use - for stdin)\n",
		"\t\t                 Format of file is:\n",
		"\t\t                 SUBTREE:DEVICE_NAME:HOSTNAME:SNMP_COMMUNITY:SNMP_PORT:SITE_FILE:COMMENT\n",
		"\t\tbasedir:         Base directory for cricket config files\n",
		"\n",
		"\tOptional parameters:\n",
		"\t\t-H|--Help:       This page\n",
		"\t\t-i|--idfile:     ID config file \n",
		"\t\t-q|--quiet:      Quiet mode\n";
	if ($Help != 1) {
                exit 1;
        }
        exit 0;
}



if(defined($readstdin)) {
	$devicefile = "<stdin>";
	$basedir = $ARGV[0];
	open(CONFIGFILE, "<&STDIN");
} else {
	$devicefile = $ARGV[0];
	$basedir = $ARGV[1];
	open(CONFIGFILE, "<$devicefile") || (print STDERR "ERROR: Unable to open $devicefile\n");
}

my($linenumber) = 0;

while(<CONFIGFILE>) {
	$linenumber++;

	chomp;

	if ($_ =~ /#.*/){
		# Ignore Commented Line
		next;
	}
	if ($_ =~ /^$/){
		# Ignore Blank Line
		next;
	}

	my($SUBTREE, $DEVICE, $HOSTNAME, $COMMUNITY, $SNMP_PORT, $SITE_FILE, $COMMENT) = split(/:/, $_, 7);

	if(!defined($SUBTREE) || $SUBTREE =~ /^\s*$/) {
		print STDERR "WARNING: $devicefile: $linenumber: Invalid subtree\n";
		next;
	}
	if(!defined($DEVICE) || $DEVICE =~ /^\s*$/) {
		print STDERR "WARNING: $devicefile: $linenumber: Invalid device name\n";
		next;
	}
	if(!defined($HOSTNAME) || $HOSTNAME =~ /^\s*$/) {
		print STDERR "WARNING: $devicefile: $linenumber: Invalid hostname\n";
		next;
	}

	if(!$quiet) {
		print "Creating $basedir/$SUBTREE/$DEVICE/Targets\n";
	}

	$hostname = $HOSTNAME;
	$community = "public";
	if(defined($COMMUNITY) && $COMMUNITY !~ /^\s*$/) {
		$community = $COMMUNITY;
	}
	$port = "161";
	if(defined($SNMP_PORT) && $SNMP_PORT !~ /^\s*$/) {
		$port = $SNMP_PORT;
	}
	$sitefile = undef;
	if(defined($SITE_FILE) && $SITE_FILE !~ /^\s*$/) {
		$sitefile = $SITE_FILE;
	}


	$config = CHIRP::CHIRP::GenConfig($hostname, $community, $port, $idfile, $sitefile);
	if(!defined($config)) {
		print STDERR "ERROR: Failed to generate configuration via $community@$hostname:$port\n";
		exit 2;
	}


	my($TARGET_DIR) = $basedir . "/" . $SUBTREE . "/" . $DEVICE;
	File::Path::mkpath($TARGET_DIR, 0, 0775);

	open(SAVE_STDOUT, ">&STDOUT");
	open(STDOUT, ">$TARGET_DIR/Targets") || (print STDERR "ERROR: Unable to open $TARGET_DIR/Targets\n");

	if(CHIRP::WriteConfig::WriteConfig($config) != 0) {
		print STDERR "ERROR: Failed to write configuration\n";
		exit 2;
	}

	close(STDOUT);
	open(STDOUT, ">&SAVE_STDOUT");
	close(SAVE_STDOUT);
}

close(CONFIGFILE);

exit 0;
